@@ -63,7 +63,7 @@ var popularActions = []*action{
 	{"actions-rs/cargo", []string{"v1"}, "v2", yamlExtYML},
 	{"actions-rs/clippy-check", []string{"v1"}, "v2", yamlExtYML},
 	{"actions-rs/toolchain", []string{"v1"}, "v2", yamlExtYML},
-	{"actions/cache", []string{"v1", "v2"}, "v3", yamlExtYML},
+	{"actions/cache", []string{"v1", "v2", "v3"}, "v4", yamlExtYML},
 	{"actions/checkout", []string{"v1", "v2", "v3"}, "v4", yamlExtYML},
 	{"actions/delete-package-versions", []string{"v1", "v2", "v3"}, "v4", yamlExtYML},
 	{"actions/download-artifact", []string{"v1", "v2", "v3"}, "v4", yamlExtYML},
@@ -95,9 +95,9 @@ var popularActions = []*action{
 	{"erlef/setup-beam", []string{"v1"}, "v2", yamlExtYML},
 	{"game-ci/unity-builder", []string{"v2"}, "v3", yamlExtYML},
 	{"getsentry/paths-filter", []string{"v1", "v2"}, "v3", yamlExtYML},
-	{"github/codeql-action/analyze", []string{"v1"}, "v2", yamlExtYML},
-	{"github/codeql-action/autobuild", []string{"v1"}, "v2", yamlExtYML},
-	{"github/codeql-action/init", []string{"v1"}, "v2", yamlExtYML},
+	{"github/codeql-action/analyze", []string{"v1", "v2"}, "v3", yamlExtYML},
+	{"github/codeql-action/autobuild", []string{"v1", "v2"}, "v3", yamlExtYML},
+	{"github/codeql-action/init", []string{"v1", "v2"}, "v3", yamlExtYML},
 	{"github/super-linter", []string{"v3", "v4"}, "v5", yamlExtYML},
 	{"githubocto/flat", []string{"v1", "v2", "v3"}, "v4", yamlExtYML},
 	{"golangci/golangci-lint-action", []string{"v1", "v2", "v3"}, "v4", yamlExtYML},
@@ -112,7 +112,7 @@ var popularActions = []*action{
 	{"nwtgck/actions-netlify", []string{"v1"}, "v2", yamlExtYML},
 	{"octokit/request-action", []string{"v1.x", "v2.x"}, "v3.x", yamlExtYML},
 	{"peaceiris/actions-gh-pages", []string{"v2", "v3"}, "v4", yamlExtYML},
-	{"peter-evans/create-pull-request", []string{"v1", "v2", "v3"}, "v4", yamlExtYML},
+	{"peter-evans/create-pull-request", []string{"v1", "v2", "v3", "v4"}, "v5", yamlExtYML},
 	{"preactjs/compressed-size-action", []string{"v1", "v2"}, "v3", yamlExtYML},
 	{"reviewdog/action-actionlint", []string{"v1"}, "v2", yamlExtYML},
 	{"reviewdog/action-eslint", []string{"v1"}, "v2", yamlExtYML},
